@@ -628,7 +628,7 @@ eog_image_get_file_info (EogImage *img,
 			*bytes = g_file_info_get_size (file_info);
 
 		if (mime_type) {
-			*mime_type = g_strdup (eog_util_get_content_type_with_fallback (file_info));
+			*mime_type = eog_util_get_mime_type_with_fallback (file_info);
 		}
 		g_object_unref (file_info);
 	}
@@ -1373,6 +1373,14 @@ eog_image_load (EogImage *img, EogImageData data2read, EogJob *job, GError **err
 	}
 
 	if (success) {
+#ifdef HAVE_LCMS
+		/* This converts an immutable pixbuf (as returned by glycin-based
+		 * loaders) to a mutable one here to avoid the conversion later
+		 * when applying the ICC profile where it may race with
+		 * thumbnail generation. See eog#334 and gdk-pixbuf#277. */
+		if (data2read & EOG_IMAGE_DATA_IMAGE && G_LIKELY(priv->image))
+			gdk_pixbuf_get_pixels (priv->image);
+#endif
 		priv->status = EOG_IMAGE_STATUS_LOADED;
 	} else {
 		priv->status = EOG_IMAGE_STATUS_FAILED;
