@@ -25,8 +25,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef __EOG_WINDOW_H__
-#define __EOG_WINDOW_H__
+#pragma once
 
 #include "eog-list-store.h"
 #include "eog-image.h"
@@ -35,6 +34,7 @@
 #include <glib-object.h>
 #include <gio/gmenu.h>
 #include <gtk/gtk.h>
+#include <handy.h>
 
 G_BEGIN_DECLS
 
@@ -84,13 +84,13 @@ typedef enum {
 } EogStartupFlags;
 
 struct _EogWindow {
-	GtkApplicationWindow win;
+	HdyApplicationWindow win;
 
 	EogWindowPrivate *priv;
 };
 
 struct _EogWindowClass {
-	GtkApplicationWindowClass parent_class;
+	HdyApplicationWindowClass parent_class;
 
 	void (* prepared) (EogWindow *window);
 };
@@ -104,7 +104,6 @@ EogWindowMode eog_window_get_mode       (EogWindow       *window);
 void          eog_window_set_mode       (EogWindow       *window,
 					 EogWindowMode    mode);
 
-GtkUIManager *eog_window_get_ui_manager (EogWindow       *window);
 GMenu        *eog_window_get_gear_menu_section (EogWindow   *window,
 						const gchar *id);
 
@@ -129,7 +128,7 @@ gboolean      eog_window_is_empty 	(EogWindow       *window);
 gboolean      eog_window_is_not_initializing (const EogWindow *window);
 
 void          eog_window_reload_image (EogWindow *window);
-GtkWidget    *eog_window_get_properties_dialog (EogWindow *window);
+GtkWidget    *eog_window_get_remote_presenter (EogWindow *window);
 
 void          eog_window_show_about_dialog (EogWindow    *window);
 void          eog_window_show_preferences_dialog (EogWindow *window);
@@ -137,5 +136,3 @@ void          eog_window_show_preferences_dialog (EogWindow *window);
 void          eog_window_close          (EogWindow *window);
 
 G_END_DECLS
-
-#endif
